@@ -1,3 +1,4 @@
+# encoding: utf-8
 # bootstrap.rb contains the minimal code to be able to launch Bundler to eventually be able
 # to retrieve the core code in the logstash-core gem which can live under different paths
 # depending on the launch context (local dev, packaged, etc)
@@ -15,6 +16,7 @@ module LogStash
     BUNDLE_DIR = ::File.join(LOGSTASH_HOME, "vendor", "bundle")
     GEMFILE_PATH = ::File.join(LOGSTASH_HOME, "Gemfile")
     LOCAL_GEM_PATH = ::File.join(LOGSTASH_HOME, 'vendor', 'local_gems')
+    CACHE_PATH = File.join(LOGSTASH_HOME, "vendor", "cache")
 
     # @return [String] the ruby version string bundler uses to craft its gem path
     def gem_ruby_version
@@ -31,6 +33,14 @@ module LogStash
       RUBY_ENGINE
     end
 
+    def windows?
+      ::Gem.win_platform?
+    end
+
+    def jruby?
+      @jruby ||= !!(RUBY_PLATFORM == "java")
+    end
+
     def logstash_gem_home
       ::File.join(BUNDLE_DIR, ruby_engine, gem_ruby_version)
     end
@@ -46,4 +56,4 @@ if $0 == __FILE__
   LogStash::Bundler.setup!({:without => [:build, :development]})
   require ARGV.shift
   LogStash::Runner.new.main(ARGV)
-end
\ No newline at end of file
+end
